@@ -1,7 +1,6 @@
 //! Interpreter module.
 //!
 use super::parser::Parser;
-use super::lexer::Lexer;
 
 #[derive(Debug)]
 /// Interpreter struct
@@ -9,8 +8,7 @@ pub struct Interpreter {
     file_name: String,
     content: String,
     imports: Vec<Box<Interpreter>>,
-    parser: Option<Parser>,
-    lexer: Lexer,
+    parser: Parser,
 }
 
 impl Interpreter {
@@ -20,17 +18,18 @@ impl Interpreter {
             file_name: arg_file_name.clone(),
             content: arg_content.clone(),
             imports: vec![],
-            parser: None,
-            lexer: Lexer::new(arg_content),
+            parser: Parser::new(arg_file_name, arg_content.clone()),
         }
     }
     /// File name accessor.
     pub fn get_name(&self) -> String { return self.file_name.clone();}
     /// Interpreter execution function
     pub fn run(&mut self) -> i32 {
-        if let Err(mut e) = self.lexer.lex() {
-            e.module_name = self.file_name.clone();
-            1
-        } else {0}
+        println!("{}:", self.file_name);
+        let lexer_result = self.parser.lex();
+        match lexer_result {
+            Ok(_) => 0,
+            Err(_) => 1,
+        }
     }
 }
\ No newline at end of file
