@@ -1,8 +1,6 @@
-pub mod lexer;
-// deleted and moved into the lexer
-//pub mod preproc;
 pub mod parser;
 pub mod argparser;
 pub mod run;
 pub mod version;
-pub mod errors;
\ No newline at end of file
+pub mod interpreter;
+pub mod lexer;
\ No newline at end of file
